# coding: utf-8

"""
    Chaos

     Module for testing.   # noqa: E501
"""

from setuptools import setup, find_packages  # noqa: H301

NAME="chaos"
VERSION='0.1.0'
REQUIRES=['requests==2.25.1',
    'ssm-cache==2.7',
    'urllib3>=1.25.4',
    'chardet==3.0.4',
    'certifi==2018.11.29',
    'idna==2.8',
    'six==1.12.0'
]

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

setup(
    name=NAME,
    version=VERSION,
    description="PSI Chaos module",
    author="Pearson Service Insights",
    author_email="john.torres@pearson.com",
    url="https://gitlab.com/pearson-io-swa/integrations",
    keywords=["Pearson", "PSI", "Chaos"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
     Module containing decorators to wrap functions/methods to break things.   # noqa: E501
    """
)
